%bcond_with bootstrap

Name:           easymock
Version:        4.3
Release:        %mkrel 1
Group:          Development/Java
Summary:        Easy mock objects
License:        Apache-2.0
URL:            https://www.easymock.org

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# Remove bundled binaries which cannot be easily verified for licensing
Source1:        generate-tarball.sh

Patch1:         0001-Disable-android-support.patch
Patch2:         0002-Unshade-cglib-and-asm.patch
Patch3:         0003-Fix-OSGi-manifest.patch
Patch4:         0004-Port-to-hamcrest-2.1.patch

BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(cglib:cglib)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-junit-platform)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-testng)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.junit.vintage:junit-vintage-engine)
BuildRequires:  mvn(org.objenesis:objenesis)
BuildRequires:  mvn(org.ow2.asm:asm)
BuildRequires:  mvn(org.testng:testng)
%endif
# xmvn-builddep misses this:
%if %{without bootstrap}
BuildRequires:  mvn(org.apache:apache-jar-resource-bundle)
%endif

Provides:       %{name}3 = %{version}-%{release}

%description
EasyMock provides Mock Objects for interfaces in JUnit tests by generating
them on the fly using Java's proxy mechanism. Due to EasyMock's unique style
of recording expectations, most refactorings will not affect the Mock Objects.
So EasyMock is a perfect fit for Test-Driven Development.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%pom_remove_plugin :license-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :animal-sniffer-maven-plugin core

%pom_remove_plugin :maven-gpg-plugin test-testng
%pom_remove_plugin :maven-gpg-plugin test-java8
%pom_remove_plugin :maven-gpg-plugin test-junit5

# remove android support
rm core/src/main/java/org/easymock/internal/Android*.java
rm core/src/test/java/org/easymock/tests2/ClassExtensionHelperTest.java
%pom_disable_module test-android
%pom_remove_dep :dexmaker core

# unbundle asm and cglib
%pom_disable_module test-nodeps
%pom_remove_plugin :maven-shade-plugin core

# missing test deps
%pom_disable_module test-integration
%pom_disable_module test-osgi

# remove some warning caused by unavailable plugin
%pom_remove_plugin org.codehaus.mojo:versions-maven-plugin

# retired
%pom_remove_plugin :maven-timestamp-plugin

# For compatibility reasons
%mvn_file ":easymock{*}" easymock@1 easymock3@1

# ssh not needed during our builds
%pom_xpath_remove pom:extensions

# Force Surefire to run tests with JUnit, not with TestNG
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-surefire-plugin']" \
    "<configuration><testNGArtifactName>none:none</testNGArtifactName></configuration>" core

# Workaround Java 17 compatibility issue that should be fixed in
# easymock 4.4: https://github.com/easymock/easymock/issues/274
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-surefire-plugin']/pom:configuration" \
    "<argLine>--add-opens=java.base/java.lang=ALL-UNNAMED --add-opens=java.base/java.io=ALL-UNNAMED</argLine>" core
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-surefire-plugin']/pom:configuration" \
    "<argLine>--add-opens=java.base/java.lang=ALL-UNNAMED</argLine>" test-testng
%pom_add_plugin :maven-surefire-plugin test-java8 "<configuration>
    <argLine>--add-opens=java.base/java.lang=ALL-UNNAMED</argLine></configuration>"
%pom_add_plugin :maven-surefire-plugin test-junit5 "<configuration>
    <argLine>--add-opens=java.base/java.lang=ALL-UNNAMED</argLine></configuration>"

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%license core/LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license core/LICENSE.txt



%changelog
* Thu Sep 14 2023 daviddavid <daviddavid> 4.3-1.mga10
+ Revision: 1986803
- Update to upstream version 4.3

* Mon Jul 25 2022 neoclust <neoclust> 4.2-6.mga9
+ Revision: 1871017
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 4.2-5.mga9
+ Revision: 1870230
- Fix BR for bootstrap

* Tue Jun 07 2022 neoclust <neoclust> 4.2-4.mga9
+ Revision: 1863463
- Add bootstrap mode
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Dec 06 2020 neoclust <neoclust> 4.2-2.mga8
+ Revision: 1653243
- Disable tests

* Fri Sep 11 2020 daviddavid <daviddavid> 4.2-1.mga8
+ Revision: 1624350
- Update to version 4.2

* Sat Feb 15 2020 umeabot <umeabot> 3.6-2.mga8
+ Revision: 1527603
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 3.6-1.mga8
+ Revision: 1422328
- Update to upstream version 3.6
- Rebuild to fix OSGi dependency on ASM 7

* Mon Dec 10 2018 daviddavid <daviddavid> 3.5-1.mga7
+ Revision: 1339743
- new version: 3.5 (sync with fc29)

* Tue Sep 18 2018 umeabot <umeabot> 3.4-3.mga7
+ Revision: 1261671
- Mageia 7 Mass Rebuild

* Sun May 14 2017 neoclust <neoclust> 3.4-2.mga6
+ Revision: 1101289
- New version 3.4

* Wed Mar 02 2016 neoclust <neoclust> 3.3.1-5.mga6
+ Revision: 982468
- Second rebuild of the java stack

* Sat Feb 27 2016 neoclust <neoclust> 3.3.1-4.mga6
+ Revision: 980056
- First rebuild of the java stack
- sync package easymock with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.2-4.mga5
+ Revision: 750149
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 3.2-2.mga4
+ Revision: 542057
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 dmorgan <dmorgan> 3.2-1.mga4
+ Revision: 496801
- New version

* Fri Jan 11 2013 umeabot <umeabot> 0:1.2-5.mga3
+ Revision: 349261
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 dmorgan <dmorgan> 0:1.2-4.mga3
+ Revision: 324385
- Java Stack Mass Rebuild

* Wed Jan 19 2011 dmorgan <dmorgan> 0:1.2-2.0.4.mga1
+ Revision: 24637
- Add buildrequire
- Use --execdebug
- Fix %%mkrel
- imported package easymock


* Fri Nov 26 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:1.2-12
- Fix pom filename (Resolves rhbz#655795)
- Remove clean section and buildroot declaration
- Remove versioned jars and pom files

* Thu Aug 20 2009 Alexander Kurtakov <akurtako@redhat.com> 0:1.2-11
- Bump release for rebuild.

* Thu Aug 20 2009 Alexander Kurtakov <akurtako@redhat.com> 0:1.2-10
- Disable tests.

* Mon May 18 2009 Fernando Nasser <fnasser@redhat.com> 0:1.2-9
- Update instructions for obtaining source tar ball

* Mon May 04 2009 Yong Yang <yyang@redhat.com> 0:1.2-8
- Rebuild with maven2-2.0.8 built in non-bootstrap mode

* Wed Mar 18 2009 Yong Yang <yyang@redhat.com>  0:1.2-7
- merge from JPP-6
- rebuild with new maven2 2.0.8 built in bootstrap mode

* Mon Feb 02 2009 David Walluck <dwalluck@redhat.com> 0:1.2-6
- fix component-info.xml

* Mon Feb 02 2009 David Walluck <dwalluck@redhat.com> 0:1.2-5
- remove unneeded maven flag

* Mon Feb 02 2009 David Walluck <dwalluck@redhat.com> 0:1.2-4
- add repolib

* Fri Jan 30 2009 Will Tatam <will.tatam@red61.com> 1.2-3.jpp5
- Inital JPP-5 Build

* Fri Jan 09 2009 Yong Yang <yyang@redhat.com> 1.2-2jpp.1
- Imported from dbhole's maven 2.0.8 packages, initial building on jpp6

* Fri Apr 11 2008 Deepak Bhole <dbhole@redhat.com> 1.2-1jpp.1
- Import from JPackage
- Add pom file

* Fri Feb 24 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.2-1jpp
- Update to 1.2 keeping only java 1.4 requirement

* Fri Feb 24 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.1-3jpp
- drop java-1.3.1 requirement

* Mon Oct 04 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.1-2jpp
- Fixed Url, Summary, Description and License

* Mon Oct 04 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.1-1jpp
- First JPackage release
